config

package
v1.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 2, 2022 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version string

Functions

This section is empty.

Types

type Config

type Config struct {
	// Users Array of users allowed to send mail.
	// Each user must authenticate with a login password.
	Users []*model.User `yaml:"users" toml:"users"`

	// Secure is set to true if a least one user is defined.
	// In secure mode, only authenticated users can send mails.
	Secure bool

	// Debug if true, the router will be more verbose.
	Debug bool

	// LogFile holds the configuration used for the log file
	LogFile logFile `yaml:"logfile"`
}
var C *Config

func (*Config) GetUser

func (c *Config) GetUser(username string) *model.User

GetUser gets a user from name

Jump to