Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Version string
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// Users Array of users allowed to send mail.
// Each user must authenticate with a login password.
Users []*model.User `yaml:"users" toml:"users"`
// Secure is set to true if a least one user is defined.
// In secure mode, only authenticated users can send mails.
Secure bool
// Debug if true, the router will be more verbose.
Debug bool
// LogFile holds the configuration used for the log file
LogFile logFile `yaml:"logfile"`
}
var C *Config
Click to show internal directories.
Click to hide internal directories.